@@ -180,7 +180,7 @@ def pattern_replace(pattern, object):
             # try to apply the indexing instructions, indicated through '[...]'
             if ext:
                 try:
-                    return eval('val%s' % (ext))  # noqa: PGH001
+                    return eval('val%s' % (ext))  # noqa: PGH001, S307
                 except SyntaxError:
                     return val
             return val
